/*
 * User: Tom
 * Date: 1-aug-2004
 * Time: 23:44:02
 */
package com.tombrus.imageConverter;

import java.awt.image.BufferedImage;
import java.util.ArrayList;

public class Job implements Runnable {
    boolean       verbose;
    boolean       follow;
    JobStep[]     steps;

    public BufferedImage getImage() {
        return image;
    }

    public void setImage(BufferedImage image) {
        this.image = image;
    }

    BufferedImage image;

    public Job(String[] args) {
        final ArrayList list = new ArrayList();
        for (int i = 0; i<args.length; i++) {
            String arg = args[i];
            if (arg.equals("-v") || arg.equals("-verbose")) {
                verbose = true;
            } else if (arg.equals("-f") || arg.equals("-follow")) {
                follow = true;
                verbose("init - verbose = on");
            }else if (arg.charAt(0)=='-') {
                final String name = arg.substring(1,arg.length());
                try {
                    final Class   clazz   = Class.forName(JobStep.class.getPackage().getName()+".jobs."+name);
                    final JobStep jobstep = (JobStep) clazz.newInstance();
                    i = jobstep.initFrom(this,args,i);
                    list.add(jobstep);
                    verbose("init - added "+jobstep);
                } catch (ClassNotFoundException e) {
                    throw new Error("no such command: "+name);
                } catch (IllegalAccessException e) {
                    e.printStackTrace();
                } catch (InstantiationException e) {
                    e.printStackTrace();
                }
            }else {
                throw new Error("unexpected argument: "+arg);
            }
        }
        steps = (JobStep[]) list.toArray(new JobStep[list.size()]);
        verbose("init - got "+steps.length+" jobsteps.\n");
    }

    public void verbose(String s) {
        if (verbose) {
            System.err.println(s);
        }
    }

    public boolean isRunNeeded() {
        for (int i = 0; i<steps.length; i++) {
            JobStep step = steps[i];
            if (step.isRunNeeded()) {
                verbose("needed - run needed for "+step);
                return true;
            }
        }
        verbose("needed - no run needed");
        return false;
    }

    public void run() {
        for (int i = 0; i<steps.length; i++) {
            JobStep step = steps[i];
            verbose("running - "+step);
            step.run();
        }
    }
}